@@ -396,6 +396,8 @@ class ShipAction1Packet:
             return HelmSetWarpPacket.decode(packet)
         if subtype_index == 1:
             return SetMainScreenPacket.decode(packet)
+        if subtype_index == 2:
+            return SetWeaponsTargetPacket.decode(packet)
         if subtype_index == 3:
             return ToggleAutoBeamsPacket.decode(packet)
         if subtype_index == 4:
@@ -404,16 +406,206 @@ class ShipAction1Packet:
             return HelmRequestDockPacket.decode(packet)
         if subtype_index == 10:
             return ToggleRedAlertPacket.decode(packet)
+        if subtype_index == 11:
+            return SetBeamFreqPacket.decode(packet)
         if subtype_index == 13:
             return SetShipPacket.decode(packet)
         if subtype_index == 14:
             return SetConsolePacket.decode(packet)
+        if subtype_index == 15:
+            return ReadyPacket.decode(packet)
+        if subtype_index == 16:
+            return SciSelectPacket.decode(packet)
+        if subtype_index == 17:
+            return CaptainSelectPacket.decode(packet)
+        if subtype_index == 18:
+            return GameMasterSelectPacket.decode(packet)
+        if subtype_index == 19:
+            return SciScanPacket.decode(packet)
+        if subtype_index == 22:
+            return SetShipSettingsPacket.decode(packet)
+        if subtype_index == 24:
+            return HelmToggleReversePacket.decode(packet)
+        if subtype_index == 25:
+            return Ready2Packet.decode(packet)
         if subtype_index == 26:
             return TogglePerspectivePacket.decode(packet)
         if subtype_index == 27:
             return ClimbDivePacket.decode(packet)
         raise SoftDecodeFailure()
 
+class SciScanPacket(ShipAction1Packet):
+    def __init__(self, target):
+        self.target = target
+
+    def encode(self):
+        return pack('II', 19, self.target)
+
+    @classmethod
+    def decode(cls, packet):
+        _idx, tgt = unpack('II', packet)
+        return cls(tgt)
+
+    def __str__(self):
+        return "<SciScanPacket target={0!r}>".format(self.target)
+
+class CaptainSelectPacket(ShipAction1Packet):
+    def __init__(self, object):
+        self.object = object
+
+    def encode(self):
+        if self.object is not None:
+            return pack('II', 17, self.object)
+        else:
+            return pack('II', 17, 1)
+
+    @classmethod
+    def decode(cls, packet):
+        _idx, tgt = unpack('II', packet)
+        if tgt != 1:
+            return cls(tgt)
+        else:
+            return cls(None)
+
+    def __str__(self):
+        return "<CaptainSelectPacket object={0!r}>".format(self.object)
+
+class GameMasterSelectPacket(ShipAction1Packet):
+    def __init__(self, object):
+        self.object = object
+
+    def encode(self):
+        if self.object is not None:
+            return pack('II', 18, self.object)
+        else:
+            return pack('II', 18, 1)
+
+    @classmethod
+    def decode(cls, packet):
+        _idx, tgt = unpack('II', packet)
+        if tgt != 1:
+            return cls(tgt)
+        else:
+            return cls(None)
+
+    def __str__(self):
+        return "<GameMasterSelectPacket object={0!r}>".format(self.object)
+
+class SciSelectPacket(ShipAction1Packet):
+    def __init__(self, object):
+        self.object = object
+
+    def encode(self):
+        if self.object is not None:
+            return pack('II', 16, self.object)
+        else:
+            return pack('II', 16, 1)
+
+    @classmethod
+    def decode(cls, packet):
+        _idx, tgt = unpack('II', packet)
+        if tgt != 1:
+            return cls(tgt)
+        else:
+            return cls(None)
+
+    def __str__(self):
+        return "<SciSelectPacket object={0!r}>".format(self.object)
+
+class SetWeaponsTargetPacket(ShipAction1Packet):
+    def __init__(self, object):
+        self.object = object
+
+    def encode(self):
+        if self.object is not None:
+            return pack('II', 2, self.object)
+        else:
+            return pack('II', 2, 1)
+
+    @classmethod
+    def decode(cls, packet):
+        _idx, tgt = unpack('II', packet)
+        if tgt != 1:
+            return cls(tgt)
+        else:
+            return cls(None)
+
+    def __str__(self):
+        return "<SetWeaponsTargetPacket object={0!r}>".format(self.object)
+
+class SetBeamFreqPacket(ShipAction1Packet):
+    def __init__(self, freq):
+        self.freq = freq
+
+    def encode(self):
+        return pack('II', 11, self.freq)
+
+    @classmethod
+    def decode(cls, packet):
+        _idx, freq = unpack('II', packet)
+        return cls(freq)
+
+    def __str__(self):
+        return "<SetBeamFreqPacket freq={}>".format(self.freq)
+
+class HelmToggleReversePacket(ShipAction1Packet):
+    def encode(self):
+        return b'\x18\x00\x00\x00\x00\x00\x00\x00'
+
+    @classmethod
+    def decode(cls, packet):
+        if packet != b'\x18\x00\x00\x00\x00\x00\x00\x00':
+            raise ValueError('Unexpected payload in reverse packet')
+        return cls()
+
+    def __str__(self):
+        return '<HelmToggleReversePacket>'
+
+class ReadyPacket(ShipAction1Packet):
+    def encode(self):
+        return b'\x0f\x00\x00\x00\x00\x00\x00\x00'
+
+    @classmethod
+    def decode(cls, packet):
+        if packet != b'\x0f\x00\x00\x00\x00\x00\x00\x00':
+            raise ValueError('Unexpected payload in ready packet')
+        return cls()
+
+    def __str__(self):
+        return '<ReadyPacket>'
+
+class Ready2Packet(ShipAction1Packet):
+    def encode(self):
+        return b'\x19\x00\x00\x00\x00\x00\x00\x00'
+
+    @classmethod
+    def decode(cls, packet):
+        if packet != b'\x19\x00\x00\x00\x00\x00\x00\x00':
+            raise ValueError('Unexpected payload in ready2 packet')
+        return cls()
+
+    def __str__(self):
+        return '<Ready2Packet>'
+
+class SetShipSettingsPacket(ShipAction1Packet):
+    def __init__(self, drive, type, name):
+        self.drive = drive
+        self.type = type
+        self.name = name
+
+    def encode(self):
+        return pack('IIIIu', 0x16, self.drive.value, self.type.value, 1, self.name)
+
+    @classmethod
+    def decode(cls, packet):
+        _id, drv, typ, _unk, name = unpack('IIIIu', packet)
+        return cls(drive=DriveType(drv),
+                   type=ShipType(typ),
+                   name=name)
+
+    def __str__(self):
+        return '<SetShipSettingsPacket drive={0!r} type={1!r} name={2!r}>'.format(self.drive, self.type, self.name)
+
 class HelmRequestDockPacket(ShipAction1Packet):
     def encode(self):
         return b'\x07\x00\x00\x00\x00\x00\x00\x00'
@@ -566,7 +758,7 @@ class ShipAction3Packet:
             return HelmSetImpulsePacket.decode(packet)
         if subtype_index == 1:
             return HelmSetSteeringPacket.decode(packet)
-        if subtype_index == 4:
+        if subtype_index == 5:
             return HelmJumpPacket.decode(packet)
         raise SoftDecodeFailure()
 
@@ -606,7 +798,7 @@ class HelmJumpPacket(ShipAction3Packet):
         self.distance = distance
 
     def encode(self):
-        return pack('Iff', 4, self.bearing / (math.pi * 2), self.distance / 50)
+        return pack('Iff', 5, self.bearing / (math.pi * 2), self.distance / 50)
 
     @classmethod
     def decode(cls, packet):
@@ -616,6 +808,35 @@ class HelmJumpPacket(ShipAction3Packet):
     def __str__(self):
         return '<HelmJumpPacket bearing={0!r} distance={1!r}>'.format(self.bearing, self.distance)
 
+@packet(0xb83fd2c4)
+class BeamFiredPacket:
+    def __init__(self, object, port, origin, target, x, y, z, auto):
+        self.object = object
+        self.port = port
+        self.origin = origin
+        self.target = target
+        self.x = x
+        self.y = y
+        self.z = z
+        self.auto = auto
+
+    def encode(self):
+        return pack('IIIIIIIIfffI',
+                    self.object, 0, 1200,
+                    self.port,
+                    1, 1,
+                    self.origin, self.target,
+                    self.x, self.y, self.z,
+                    0 if self.auto else 1)
+
+    @classmethod
+    def decode(cls, packet):
+        object, _unk1, _unk2, port, _unk3, _unk4, origin, target, x, y, z, auto = unpack('IIIIIIIIfffI', packet)
+        return cls(object, port, origin, target, x, y, z, [True, False][auto])
+
+    def __str__(self):
+        return '<BeamFiredPacket object={object} port={port} origin={origin} target={target} position=({x}, {y}, {z}) automatic={auto!r}>'.format(**self.__dict__)
+
 def encode(packet, provenance=PacketProvenance.client):
     encoded_block = packet.encode()
     block_len = len(encoded_block)
